"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readConfig = void 0;
const debug_1 = __importDefault(require("debug"));
const lilconfig_1 = require("lilconfig");
const util_1 = require("./util");
const debug = (0, debug_1.default)('midnight-smoker:config');
async function loadEsm(filepath) {
    return import(filepath);
}
const DEFAULT_OPTS = Object.freeze({
    loaders: { '.mjs': loadEsm, '.js': loadEsm },
    searchPlaces: [
        'package.json',
        '.smokerrc.json',
        '.smokerrc.js',
        '.smokerrc.cjs',
        '.smokerrc.mjs',
        'smoker.config.json',
        'smoker.config.js',
        'smoker.config.cjs',
        'smoker.config.mjs',
        '.config/smokerrc.json',
        '.config/smokerrc.js',
        '.config/smokerrc.cjs',
        '.config/smokerrc.mjs',
        '.config/smoker.config.json',
        '.config/smoker.config.js',
        '.config/smoker.config.cjs',
        '.config/smoker.config.mjs',
    ],
});
const ARRAY_KEYS = new Set(['add', 'workspace', 'pm', 'script', 'scripts']);
async function readConfig() {
    const result = await (0, lilconfig_1.lilconfig)('smoker', DEFAULT_OPTS).search();
    if (result?.config && !result.config.isEmpty) {
        debug('Found config at %s', result.filepath);
        let config = result.config;
        // I love ESM, really I do
        if ('default' in config) {
            config = config.default;
        }
        // TODO better validation
        for (const key of ARRAY_KEYS) {
            const value = config[key];
            if (value) {
                config[key] = (0, util_1.castArray)(value);
            }
        }
        /**
         * consolidate these two because at least one script is required by the
         * CLI, and we will stuff `script` into `process.argv` if it is present
         * to avoid the failure case of no scripts being present.
         */
        config.script = [...(config.script ?? []), ...(config.scripts ?? [])];
        delete config.scripts;
        debug('Loaded config: %O', config);
        return config;
    }
    return {};
}
exports.readConfig = readConfig;
//# sourceMappingURL=config.js.map